@@ -22,11 +22,11 @@ RDF::Trine::Store::File - Using a file with N-Triples as triplestore
 
 =head1 VERSION
 
-Version 0.11_2
+Version 0.02
 
 =cut
 
-our $VERSION = '0.11_2';
+our $VERSION = '0.02';
 
 
 =head1 SYNOPSIS
@@ -60,44 +60,21 @@ sub new {
   my $self  = bless(
 		    {
 		     file => $file,
-		     fu	  => $fu,
-			  parser => 'ntriples',
+		     fu   => $fu,
 		     nser => RDF::Trine::Serializer::NTriples->new,
 		     log  => Log::Log4perl->get_logger("rdf.trine.store.file")
 		    }, $class);
   return $self;
 }
 
-=head2 new_with_string('File;'.$filename)
-
-A constructor, takes a string config as parameter. If the file doesn't
-exist, it will be created. The string will typically begin with C<File;>, e.g.
-
-  my $store = RDF::Trine::Store::File->new_with_string('File;/path/to/file.nt');
-
-=cut
 
 sub _new_with_string {
-  my ($class, $filename) = @_;
-  return $class->new($filename);
-}
-
-=head2 new_with_config({ storetype => 'File', file => $filename});
-
-A constructor, takes a hashref config as parameter. If the file doesn't
-exist, it will be created. It needs to have a C<storetype> key with C<File> as the value, e.g.
-
-  my $store = RDF::Trine::Store::File->new_with_config({ storetype => 'File', file => $filename});
-
-
-=cut
-
-sub _new_with_config {
   my $class = shift;
-  my $config = shift;
-  return $class->new($config->{file});
+  return $class->new(shift);
 }
 
+
+
 =head2 temporary_store
 
 Constructor that creates a temporary file to work on.
@@ -125,7 +102,6 @@ sub add_statement {
   my $mm = RDF::Trine::Model->temporary_model;
   $mm->add_statement($st);
   $self->{log}->debug("Attempting addition of statement");
-  $self->{log}->trace("with terms " . $st->as_string);
   my $fd = File::Data->new($self->{file});
   $fd->append($self->{nser}->serialize_model_to_string($mm));
   return;
@@ -133,7 +109,7 @@ sub add_statement {
 
 =head2 get_statements($subject, $predicate, $object)
 
-Returns a iterator object of all statements matching the specified subject,
+Returns a stream object of all statements matching the specified subject,
 predicate and objects. Any of the arguments may be undef to match any value.
 
 =cut
@@ -141,10 +117,10 @@ predicate and objects. Any of the arguments may be undef to match any value.
 sub get_statements {
   my $self = shift;
   my @lines = $self->_search_statements(@_);
-  my $parser = RDF::Trine::Parser->new($self->{parser});
+  my $parser = RDF::Trine::Parser->new( 'ntriples' );  
   my $mm = RDF::Trine::Model->temporary_model;
   $parser->parse_into_model( '', join('', @lines), $mm );
-  return $mm->as_stream;
+  return $mm->get_statements(undef, undef, undef, undef);
 }
 
 =head2 count_statements($subject, $predicate, $object)
@@ -187,10 +163,7 @@ sub remove_statement {
   $mm->add_statement($st);
   $self->{log}->debug("Attempting removal of statement");
   my $fd = File::Data->new($self->{file});
-  my $triple = $self->{nser}->serialize_model_to_string($mm);
-  $triple =~ s/\^/\\^/g;
-  $triple =~ s/\\u/\\\\u/g;
-  $fd->REPLACE($triple, '');
+  $fd->REPLACE($self->{nser}->serialize_model_to_string($mm), '');
   return;
 }
 
@@ -216,18 +189,15 @@ sub remove_statements {
 
 =head2 get_contexts
 
-Will return an empty iterator as this triple store does not support contexts.
+Contexts are not supported for this store.
 
 =cut
 
 
 sub get_contexts {
-  my $self = shift;
-  $self->{log}->warn("Contexts not supported for the triple File store");
-  return RDF::Trine::Iterator->new([]);
+  croak "Contexts not supported for the File store";
 }
 
-
 =head2 size
 
 Returns the number of statements in the store. Breaks if there are
@@ -260,9 +230,7 @@ Permanently removes the store file and its data.
 =cut
 
 sub nuke {
-  my $self = shift;
-  unlink $self->{file};
-  return $self;
+  unlink $_[0]->{file};
 }
 
 # Private method to create a regexp to be used in all kind of searching
@@ -271,9 +239,8 @@ sub _search_regexp {
   my $self = shift;
   my $i = 1;
   my @stmt;
-  foreach my $term (@_[0..2]) { # Create an array of RDF terms for later replacing for variables, discard context
+  foreach my $term (@_) { # Create an array of RDF terms for later replacing for variables
     my $outterm = $term || RDF::Trine::Node::Resource->new("urn:rdf-trine-store-file-$i");
-    $outterm = RDF::Trine::Node::Resource->new("urn:rdf-trine-store-file-$i") if ($outterm->isa('RDF::Trine::Node::Variable'));
     push(@stmt, $outterm);
     $i++;
   }
@@ -282,11 +249,8 @@ sub _search_regexp {
   my $triple_resources = $self->{nser}->serialize_model_to_string($mm);
   chomp($triple_resources);
   $triple_resources =~ s/\.\s*$/\\./;
-  $triple_resources =~ s/<urn:rdf-trine-store-file-1>/(?:<.*?>|_\:\\w+?)/;
-  $triple_resources =~ s/urn:rdf-trine-store-file-2/.*?/g;
-  $triple_resources =~ s/<urn:rdf-trine-store-file-3>/.+/;
-  $triple_resources =~ s/\^/\\^/g;
-  $triple_resources =~ s/\\u/\\\\u/g;
+  $triple_resources =~ s/urn:rdf-trine-store-file-(1|2)/.*?/g;
+  $triple_resources =~ s/<urn:rdf-trine-store-file-3>/.*/;
   my $out = '(' . $triple_resources . '\n)';
   $self->{log}->debug("Search regexp: $out");
   return $out;
@@ -298,7 +262,7 @@ This module is intended mostly as a simple backend to dump data to a
 file and do as little as possible in memory. Thus, it is mostly
 suitable in cases where a lot of data is written to file. It should be
 possible to use it as a SPARQL store with L<RDF::Query>, but the
-performance is likely to be somewhere between terrible and abysmal,
+performance is likely to be somewhere between terrible and abyssmal,
 so don't do that unless you are prepared to be waiting around.
 
 On the good side, adding statements should be pretty fast, as it just
@@ -320,8 +284,7 @@ because it would dramatically reduce C<add_statement> performance and
 thus kill the main use case for this module. Perhaps it could be made
 optional at some point, but for now, just be aware that this may not
 always return the right counts if two identical statements are
-inserted and possibly produce unexpected results if you against the
-advice above should attempt to use this a store for SPARQL.
+inserted.
 
 
 I've decided to use L<File::Data> to actually do the work with the
@@ -332,14 +295,16 @@ place to go and fix it.
 
 =head1 TODO
 
-This is beta-quality software but it has a pretty comprehensive test
-suite. These are some things that could be done:
+This is alpha-quality software and there are some important things to
+do before it is ready for general use:
 
 =over
 
-=item * Support bulk operations (somewhat less important)
+=item * Use the Test::RDF::Trine::Store test suite (without it, this module is arguably not well tested).
 
-=item * Find a way to do duplicate checking efficiently
+=item * Support more constructors (e.g. C<new_with_config>)
+
+=item * Support bulk operations (somewhat less important)
 
 =back
 
@@ -394,7 +359,7 @@ L<http://search.cpan.org/dist/RDF-Trine-Store-File/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2011-2012,2014 Kjetil Kjernsmo.
+Copyright 2011 Kjetil Kjernsmo.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
